@@ -69,11 +69,6 @@ class TestProfileWithCaching(unittest.TestCase):
     def tearDown(self):
         setRequest(None)
 
-    def assertBrowserEmpty(self, browser):
-        # assert that browser.contents is an empty bytes/string/unicode.
-        self.assertIsInstance(browser.contents, (six.binary_type, six.text_type))
-        self.assertFalse(browser.contents)
-
     def test_composite_viewsxx(self):
         # This is a clone of the same test for 'without-caching-proxy'
         # Can we just call that test from this context?
@@ -198,7 +193,11 @@ class TestProfileWithCaching(unittest.TestCase):
         browser.open(self.portal['f1']['d1'].absolute_url())
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        # We MUST have an empty byte, not text, otherwise it is an indication that we
+        # get a possibly wrong Content-Type in a 304 status.
+        # See https://github.com/zopefoundation/Zope/issues/1089.
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request the anonymous folder
         now = stable_now()
@@ -266,7 +265,8 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Edit the page to update the etag
         testText2 = 'Testing... body two'
@@ -359,7 +359,8 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request the authenticated rss feed
         now = stable_now()
@@ -489,7 +490,8 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request an image scale
         now = stable_now()
@@ -540,7 +542,8 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request a large datafile (over 64K) to test files that use
         # the "response.write()" function to initiate a streamed response.
