@@ -57,11 +57,6 @@ class TestProfileWithoutCaching(unittest.TestCase):
     def tearDown(self):
         setRequest(None)
 
-    def assertBrowserEmpty(self, browser):
-        # assert that browser.contents is an empty bytes/string/unicode.
-        self.assertIsInstance(browser.contents, (six.binary_type, six.text_type))
-        self.assertFalse(browser.contents)
-
     def test_composite_views(self):
 
         catalog = self.portal['portal_catalog']
@@ -193,7 +188,11 @@ class TestProfileWithoutCaching(unittest.TestCase):
         browser.open(self.portal['f1']['d1'].absolute_url())
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        # We MUST have an empty byte, not text, otherwise it is an indication that we
+        # get a possibly wrong Content-Type in a 304 status.
+        # See https://github.com/zopefoundation/Zope/issues/1089.
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request the anonymous folder
         now = stable_now()
@@ -260,7 +259,8 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Edit the page to update the etag
         testText2 = 'Testing... body two'
@@ -346,7 +346,8 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request the authenticated rss feed
         now = stable_now()
@@ -432,7 +433,8 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request an image scale
         now = stable_now()
@@ -481,7 +483,8 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertBrowserEmpty(browser)
+        self.assertEqual(b'', browser.contents)
+        self.assertFalse(browser.headers.get('Content-Type'))
 
         # Request a large datafile (over 64K) to test files that use
         # the "response.write()" function to initiate a streamed response.
